@@ -3,18 +3,27 @@
 guidata
 =======
 
-Based on the Qt Python binding module PyQt4, `guidata` is a Python library
-generating graphical user interfaces for easy dataset editing and display.
-It also provides helpers and application development tools for PyQt4.
+Based on the Qt library (``PyQt4`` and ``PyQt5`` are currently supported), 
+`guidata` is a Python library generating graphical user interfaces for easy 
+dataset editing and display. It also provides helpers and application 
+development tools for PyQt.
 
 External resources:
-    * Bug reports and feature requests: `GoogleCode`_
+    * Python Package Index: `PyPI`_
+    * Bug reports and feature requests: `GitHub`_
     * Help, support and discussions around the project: `GoogleGroup`_
 
-.. _GoogleCode: http://guidata.googlecode.com
+.. _PyPI: https://pypi.python.org/pypi/guidata
+.. _GitHub: https://github.com/PierreRaybaut/guidata
 .. _GoogleGroup: http://groups.google.fr/group/guidata_guiqwt
 """
 
+__version__ = '1.7.3'
+
+# Dear (Debian, RPM, ...) package makers, please feel free to customize the
+# following path to module's data (images) and translations:
+DATAPATH = LOCALEPATH = ''
+
 
 #    Copyright © 2009-2010 CEA
 #    Pierre Raybaut
@@ -529,13 +538,6 @@ External resources:
 #    
 #    Version 2.0 dated 2006-09-05.
 
-
-__version__ = '1.6.1'
-
-# Dear (Debian, RPM, ...) package makers, please feel free to customize the
-# following path to module's data (images) and translations:
-DATAPATH = LOCALEPATH = ''
-
 import guidata.config
 
 def qapplication():
