@@ -281,13 +281,14 @@ class UserConfig(cp.ConfigParser):
     def get_default(self, section, option):
         """
         Get Default value for a given (section, option)
-        -> useful for type checking in 'get' method
+
+        Useful for type checking in 'get' method
         """
         section = self.__check_section_option(section, option)
         options = self.defaults.get(section, {})
         return options.get(option, NoDefault)
                 
-    def get(self, section, option, default=NoDefault):
+    def get(self, section, option, default=NoDefault, **kwargs):
         """
         Get an option
         section=None: attribute a default section name
